@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////////////////////
 // Package: easygen
 // Purpose: Easy to use universal code/text generator
-// Authors: Tong Sun (c) 2015-2019, All rights reserved
+// Authors: Tong Sun (c) 2015-2021, All rights reserved
 ////////////////////////////////////////////////////////////////////////////
 
 /*
@@ -64,6 +64,10 @@ func ReadDataFile(fileName string) EgData {
 		} else {
 			checkError(fmt.Errorf("Unsupported file extension for DataFile '%s'", fileName))
 		}
+	} else if fileName == "-" {
+		// from stdin
+		// Yaml format is a superset of JSON, it read Json file just as fine
+		return ReadYamlFile(fileName)
 	}
 	checkError(fmt.Errorf("DataFile '%s' cannot be found", fileName))
 	return nil
@@ -71,8 +75,15 @@ func ReadDataFile(fileName string) EgData {
 
 // ReadYamlFile reads given YAML file as EgData
 func ReadYamlFile(fileName string) EgData {
-	source, err := ioutil.ReadFile(fileName)
-	checkError(err)
+	var source []byte
+	var err error
+	if fileName == "-" {
+		source, err = ioutil.ReadAll(os.Stdin)
+		checkError(err)
+	} else {
+		source, err = ioutil.ReadFile(fileName)
+		checkError(err)
+	}
 
 	m := make(map[interface{}]interface{})
 
@@ -92,6 +103,7 @@ func ReadJsonFile(fileName string) EgData {
 	err = json.Unmarshal(source, &m)
 	checkError(err)
 
+	//fmt.Printf("] Input %v\n", m)
 	return m
 }
 
@@ -152,7 +164,21 @@ func Process1(t Template, wr io.Writer, fileNameTempl string, fileName string) e
 	return Execute(t, wr, fileNameT, m)
 }
 
-// Execute will execute the Template on the given data map `m`.
+// Execute0 will execute the Template given as strTempl with the given data map `m` (i.e., no template file and no data file).
+// It parses text template strTempl then applies it to to the specified data
+// object m, and writes the output to wr. If an error occurs executing the
+// template or writing its output, execution stops, but partial results may
+// already have been written to the output writer. A template may be
+// executed safely in parallel, although if parallel executions share a
+// Writer the output may be interleaved.
+func Execute0(t Template, wr io.Writer, strTempl string, m EgData) error {
+	verbose("Execute with template string: "+strTempl, 1)
+	tmpl, err := t.Parse(strTempl)
+	checkError(err)
+	return tmpl.Execute(wr, m)
+}
+
+// Execute will execute the Template from fileNameT on the given data map `m`.
 func Execute(t Template, wr io.Writer, fileNameT string, m EgData) error {
 	// 1. Check locally
 	verbose("Checking for template locally: "+fileNameT, 1)
