@@ -7,6 +7,7 @@ import (
 
 	"github.com/go-easygen/easygen"
 	"github.com/go-easygen/easygen/egCal"
+	"github.com/go-easygen/easygen/egFilePath"
 	"github.com/go-easygen/easygen/egVar"
 )
 
@@ -20,9 +21,10 @@ func ExampleExecute() {
 	easygen.Opts.Debug = 1
 
 	tmpl0 := easygen.NewTemplate().Customize()
-	tmpl := tmpl0.Funcs(easygen.FuncDefs()).Funcs(egVar.FuncDefs()).Funcs(egCal.FuncDefs())
+	tmpl := tmpl0.Funcs(easygen.FuncDefs()).Funcs(egFilePath.FuncDefs()).
+		Funcs(egVar.FuncDefs()).Funcs(egCal.FuncDefs())
 
-	// define driving data of any tye
+	// define driving data of any type
 	v0 := variable{"some-init-method"}
 	// https://godoc.org/github.com/go-easygen/easygen#Execute
 	// provide full template file name with extension
@@ -44,7 +46,3 @@ func ExampleExecute() {
 	// The colors are: red, blue, white, .
 	// The colors are: red, blue, white.
 }
-
-// To show the full code in GoDoc
-type dummyExecute struct {
-}
